@@ -434,8 +434,9 @@ class ScratchConnect:
         """
         Set the bio or 'About Me' of the profile
         :param content: The bio or the content.
+        Thanks to QuantumCodes for helping me in the error!
         """
-        data = {"bio": content}
+        data = json.dumps({"bio": content})
         return requests.put(f"https://scratch.mit.edu/site-api/users/all/{self.username}/",
                             data=data,
                             headers=self.headers,
@@ -445,8 +446,9 @@ class ScratchConnect:
         """
         Set the status or 'What I am Working On' of the profile
         :param content: The work or the content.
+        Thanks to QuantumCodes for helping me in the error!
         """
-        data = {"status": content}
+        data = json.dumps({"status": content})
         return requests.put(f"https://scratch.mit.edu/site-api/users/all/{self.username}/",
                             data=data,
                             headers=self.headers,
@@ -620,13 +622,13 @@ class ScratchConnect:
         return Studio.Studio(id=studio_id, client_username=self.username, csrf_token=self.csrf_token,
                              session_id=self.session_id, token=self.token)
 
-    def connect_project(self, project_id):
+    def connect_project(self, project_id, access_unshared=False):
         """
         Connect a Scratch Project
         :param project_id: A valid project ID
         """
         return Project.Project(id=project_id, client_username=self.username, csrf_token=self.csrf_token,
-                               session_id=self.session_id, token=self.token)
+                               session_id=self.session_id, token=self.token, unshared=access_unshared)
 
     def connect_forum_topic(self, forum_id):
         """
