@@ -1,5 +1,5 @@
 __name__ = "scratchconnect"
-__version__ = "2.1"
+__version__ = "2.4.1"
 __author__ = "Siddhesh Chavan"
 __documentation__ = "https://sid72020123.github.io/scratchconnect/"
 __doc__ = f"""
@@ -10,8 +10,9 @@ Import Statement:
 Documentation(Tutorial):
     For documentation, go to {__documentation__}
 Required Libraries:
-    requests*, re*, json*, time*, websocket-client
+    requests*, re*, json*, time*, threading*, websocket-client
     * -> In-built
+    This library also uses pyEmmiter to handle cloud events in Python.
 History:
     19/06/2021(v0.0.0.1) - First made the library and updated it.
     20/06/2021(v0.1) - Added many features.
@@ -38,6 +39,14 @@ History:
     02/10/2021(v2.0) - Updated the Cloud and Forum Class
     10/10/2021(v2.0.1) - Fixed some cloud stuff
     11/10/2021(v2.1) - Added some features to Forum Class
+    24/10/2021(v2.1.1) - Started making the scStorage Class
+    29/10/2021(v2.1.1.1) - Fixed set_bio() and set_work() and updated the scDataBase
+    30/10/2021(v2.2.5) - Updated the scStorage
+    31/10/2021(v2.2.7) - Updated the scStorage
+    25/11/2021(v2.3) - Updated the scStorage and CloudConnection
+    13/12/2021(v2.3.5) - Started making the TurbowarpCloudConnection feature and added some methods to it
+    14/12/2021(v2.4) - Updated and fixed mistakes in docs
+    09/01/2022(v2.4.1) - Code Fixes
 Credits:
     All code by Siddhesh Chavan.
 Information:
